import requests
import urllib.request
from .exceptions import *
from .info import httpbin
import json
import socket
from .ipstuff import ipstuff
import socks


class _torinfo:
    # 9050 is the default tor proxy port
    default_port = "9050"
    # 127.0.0.1's is the default ip for tor proxy
    default_ip = "127.0.0.1"
    # combine the default port and the default ip
    default_host = f"{default_ip}:{default_port}"

class _session:

    # function to return your tor proxy identity
    def identity(self, host: str=_torinfo.default_host):

        # extract host ip from host string
        ip = host.split(":")[0]
        # extract host port from host string
        port = int(host.split(":")[1])

        # setting default proxy
        socks.setdefaultproxy(socks.PROXY_TYPE_SOCKS5, ip, port)

        # setting socket
        socket.socket = socks.socksocket

        # get httpbin url to return ip
        url = httpbin.IP
        # request data
        req = urllib.request.urlopen(url)
        # encode data
        encode = req.info().get_content_charset('utf-8')

        # load data as json
        data = json.loads(req.read().decode(encode))
        # extract ip from data
        identity_ip = data["origin"]
        # lookup ip info
        ip_info = ipstuff.ipinfo(ip=identity_ip)

        # add new data into data dictionary
        data["country"] = ip_info["country"]
        data["city"] = ip_info["city"]
        data["timezone"] = ip_info["timezone"]

        # return data
        return data

class _Tor:


    # request session and adding tor proxy
    def get_session(self, host: str = _torinfo.default_host):

        # request session
        session = requests.session()
        # add tor proxy
        session.proxies = {'http': f'socks5://{host}',
                           'https': f'socks5://{host}'}

        _sess = _session()
        # return session to use
        setattr(session, "identity", _sess.identity)
        return session

    # end sesssion function
    def close_session(self, session):
        # close session
        session.close()


    # checking if proxy tor proxy is running
    def check(self, ip: str=_torinfo.default_ip, port: int=_torinfo.default_port):

        # configure socket
        sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)

        # connect to server
        connect = sock.connect_ex((ip, int(port)))

        # checking if It's alie
        if (connect == 0):

            sock.close()
            return "Alive"

        else:
            # else exception
            raise SocketConnectionError("Socket connection error")
tor = _Tor()



import urllib.request
from .exceptions import *
from .info import sock
class Proxy:
    def Handle(self, proxy: str): # creating proxy handler.
        hand = {
            'http': f'http://{proxy}',
            'https': f'http://{proxy}',
        }
        return urllib.request.ProxyHandler(hand) # return proxy handler


    def checkproxy(self, url: str, proxy: str, user_agent: str, timeout: int = int(sock.DEFAULT_SOCKET_TIMEOUT)):

        try:
            headers = {}  # creating headers dict
            headers["User-Agent"] = str(user_agent) # adding user agent to dict
            request = urllib.request.Request(url, headers=headers) # creating request


            handler = Proxy.Handle(self, proxy) # requisting handler
            opner = urllib.request.build_opener(handler) # creating request creator


            opner.open(request, timeout=timeout) # running request
            return True # if it got to this point it means that the proxy is alive
        except:
            raise ProxyFailed("Proxy failed")

proxy = Proxy()











# old test
'''
file = open("proxy.txt")
text = file.read().splitlines()
o = Proxy()
for ip in text:
    threading.Thread(target=o.checkproxy, args=[
        '',
        ip,
        '',
    ]).start()

url = ""
headers = {}
headers["User-Agent"] = ""
req = urllib.request.Request(url, headers=headers)
req.set_proxy("", "https")
res = urllib.request.urlopen(req)
print(res.read())

url = ""
headers = {}
headers["User-Agent"] = ""
req = urllib.request.Request(url, headers=headers)
proxy = ""
hnd = urllib.request.ProxyHandler({
    'http': f'http://{proxy}',
    'https': f'http://{proxy}',
})
opner = urllib.request.build_opener(hnd)
resp = opner.open(req)
print(resp.read())
'''


import json
import os
import socket
from .exceptions import *
import subprocess
import urllib.request
from .info import (
    API,
    sock,
    request
)
class DefaultInfo:
    stdout = subprocess.DEVNULL
    stderr = subprocess.DEVNULL

class ipstuffclass:

    def siteip(url: str):
        try:
            if len(url) != 0: # check url length if not 0
                hostname = socket.gethostbyname(url) # grab host url
                return hostname
            else:
                raise LengthError("Invalid url length") # Invalid url length error.
        except:
            raise SiteHostNameRequestError("Request host name error") # Request host name error


    def checkrdp(ip: str, timeout=int(sock.DEFAULT_SOCKET_TIMEOUT)):
        port = int(sock.RDP_PORT) # the specific port for rdp
        return ipstuffclass.portscan(ip, port, timeout) # checking if port is open


    def checkssh(ip: str, timeout=int(sock.DEFAULT_SOCKET_TIMEOUT)):
        port = int(sock.SSH_PORT) # the specific port for ssh
        return ipstuffclass.portscan(ip, port, timeout) # checking if port is open


    def checkip(ip: str):
        if os.name == "nt": # checking if windows os or else..
            command = f"ping {ip} -n 1"
        else:
            command = f"ping {ip} -c 1"
        res = subprocess.Popen(command, stdout=DefaultInfo.stdout, stderr=DefaultInfo.stderr) # run the command
        res.wait()
        if res.returncode == 0: # if return code is 0 there was no error on the ping else there is an error
            return True
        else:
            return False

    def ipinfo(ip: str, timeout: int= request.DEFAULT_REQUEST_TIMEOUT):
        if len(ip) == 0: # if input ip length is equal o 0
            raise LengthError("IP length error")
        url = API.IPINFO_API + "/" + ip # process request url
        try:
            request = urllib.request.urlopen(url, timeout=timeout) # preform request

            encode = request.info().get_content_charset('utf-8') # encode content

            data = json.loads(request.read().decode(encode)) # load content to json
            return data
        except Exception as error:
            raise error


    def myip(find:str=None, *args):
        url = API.IPINFO_API

        try:

            req = urllib.request.urlopen(url, timeout=request.DEFAULT_REQUEST_TIMEOUT)

            encode = req.info().get_content_charset('utf-8')

            data = json.loads(req.read().decode(encode))

            if find == None:
                return data
            else:
                return data[find]
        except Exception as error:
            return error
ipstuff = ipstuffclass


import hek

# adding host manually
host = "127.0.0.1:9050"

# request session
session = hek.tor.get_session(host="127.0.0.1:9050")
# request your proxy identity..
identity = session.identity(host=host)
# print proxy identity
print(identity)


class SiteHostNameRequestError(LookupError):
    """Request host name error"""

class LengthError(ValueError):
    """ length error exception """
class ProxyFailed(ConnectionRefusedError):
    """ Proxy failed to connect """
class FileNotFound(FileNotFoundError):
    """ if file not found """
class ExifExtractError(InterruptedError):
    """ exif error """
class SocketConnectionError(ConnectionError):
    """ socket connection error """
class OperatingSystemERROR(OSError):
    """ operating system error """

class ArpError(InterruptedError):
    """ arp error """



import subprocess
import os
from .info import Tools
from .exceptions import *


class Net_info: # info container
    op = ["nt"]
    # thous who contain monitor_ are for monitor functions
    monitor_shell = True # is shell
    monitor_stdout = subprocess.PIPE # being able to read response
    monitor_stderr = subprocess.DEVNULL # throw error to null
    # thous who contain arp_ are for Arp functions
    arp_shell = True
    arp_stdout = subprocess.DEVNULL
    arp_stderr = subprocess.DEVNULL
    arp_device = None
    arp_router = None

    # thous who contain wireshark_ are for wireshark functions
    wireshark_shell = True
    wireshark_stdout = subprocess.DEVNULL
    wireshark_stderr = subprocess.DEVNULL
    wireshark_device = None
class Net:
    def monitor_start(self, name: str="wlan0"):
        if os.name in Net_info.op: # making sure that os supported
            raise OperatingSystemERROR("this operating system is not supported")
        # process command and adding adapter name
        command = Tools.aircrack.MONITOR_START + ' ' + name
        # running command then read and decode it
        result = subprocess.Popen(
            command,
            shell=Net_info.monitor_shell,
            stdout=Net_info.monitor_stdout,
            stderr=Net_info.monitor_stderr
        ).stdout.read().decode()
        # return command decoded result
        return result

    def monitor_stop(self, name: str = "wlan0mon"):
        if os.name in Net_info.op:  # making sure that os supported
            raise OperatingSystemERROR("this operating system is not supported")
        # process command and adding adapter name
        command = Tools.aircrack.MONITOR_STOP + ' ' + name
        # running command then read and decode it
        result = subprocess.Popen(
            command,
            shell=Net_info.monitor_shell,
            stdout=Net_info.monitor_stdout,
            stderr=Net_info.monitor_stderr
        ).stdout.read().decode()

        # return command decoded result
        return result



class Arp:

    def start_arp(self, interface: str="wlan0", router:str=Net_info.arp_router, device:str=Net_info.arp_device):
        if os.name in Net_info.op:  # making sure that os supported
            raise OperatingSystemERROR("this operating system is not supported")

        # process command and adding interface name, router ip and device ip
        command = Tools.ettercap.ARP_START.replace("(interface)", interface).replace("(router)", router).replace("(device)", device)
        result = subprocess.Popen(
            command,
            shell=Net_info.arp_shell,
            stdout=Net_info.arp_stdout,
            stderr=Net_info.arp_stderr
        )

        result.wait()
        # If command interrupted error
        if result.returncode != 0:
            raise ArpError("running Arp error.")

        return "ended"

class Wireshark:


    def monitor_device(self, interface: str="wlan0", device:str=None, http=False):
        if os.name in Net_info.op:  # making sure that os supported
            raise OperatingSystemERROR("this operating system is not supported")

        # process command and adding interface and device ip
        command = Tools.wireshark.MONITOR_DEVICE.replace("(interface)", interface).replace("(device)", device)


        # running command
        result = subprocess.Popen(
            command,
            shell=Net_info.wireshark_shell,
            stdout=Net_info.wireshark_stdout,
            stderr=Net_info.wireshark_stderr
        )
        result.wait() # wait for command end

        # return command status code
        return result.returncode


net = Net()
arp = Arp()
wireshark = Wireshark()


import hek

#hek.screen.screenshot(filename="hi.png")

'''
frame = hek.screen.screen_frame()
print(frame)
'''
'''
hek.screen.capture_video(filename="name.avi", seconds=3)
'''

#hek.webcam.webcamshot(filename="te.png")

#hek.webcam.capture_video(filename="webname.avi", seconds=3)


import subprocess

import psutil, os, sys
from .info import system as si
import urllib.request




class _Process:


    def kill_process(self, name=None, pid=None, force=True):

        if os.name == "nt":

            if name != None:

                cmd = f"taskkill /IM {name} /F"

                if not force:
                    cmd.replace(" /F", "")

            elif pid != None:

                cmd = f"taskkill /PID {pid} /F"

                if not force:
                    cmd.replace(" /F", "")
        else:

            if name != None:

                cmd = f"killall {name}"

            elif pid != None:

                cmd = f"kill -9 {pid}"

        result = _Process._run_command(self, cmd)

        return result.returncode

    def getnamebypid(self, pid: str):
        if os.name == "nt":
            cmd = "wmic process get description, processid"
            key = 0
            value = 1
        else:
            cmd = "top -n 1"
            key = 1
            value = 12
        return _Process._by_commands(self, cmd, key, value, pid)

    def getpidbyname(self, name: str):
        if os.name == "nt":
            cmd = "wmic process get description, processid"
            key = 0
            value = 1
        else:
            cmd = "top -n 1"
            key = 12
            value = 1
        return _Process._by_commands(self, cmd, key, value, name)

    def _by_commands(self, cmd, key, value, target):
        command = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE)

        stdout = command.stdout.read().decode('utf-8')
        for line in stdout.splitlines():
            try:
                line = line.split()
                if line[key] == target:
                    return line[value]
            except:
                pass
        return None





    def _run_command(self, command, shell=True, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL):
            result = subprocess.Popen(
                command,
                shell=shell,
                stdout=stdout,
                stderr=stderr
            )
            result.wait()
            return result



class System:

    def __init__(self):
        self.process = _Process()
    def oname(self, what: str = None):
        if what:
            platform = what
        else:
            platform = sys.platform

        for key, value in si._SYS_PLATFORMS.items():
            if isinstance(value, list):
                for v in value:
                    if v == platform:
                        return key
            else:
                if value == platform:
                    return key
        else:
            return platform


    # get current username
    def username(self, fix=True):

        # get username data
        data = psutil.Process().username()

        # checking os
        if os.name == "nt":
            # if fix is False It'll return devicename\username
            if fix == True:
                if '\\' in data:
                    # split username from devicename
                    user = data.split("\\")[1]
                    return user
            else:
                # return all data without spliting
                return data
        else:
            # if is not windows os It'll just return data
            return data

    def download_content(self, url: str, path: str = None):
        # download link content

        # checking if given path
        if path != None:
            # checking if path containing folder
            if "\\" in path:
                # extract file name from path
                filename = url.split('\\')[-1]
            else:
                # if the path doesn't contain folders
                filename = path
        else:
            # if path is not given It'll just extract the file name from the url
            filename = url.split('/')[-1]
        # download content ..
        urllib.request.urlretrieve(url, filename)

        return True


system = System()



from .ipstuff import ipstuff
from .proxy import proxy
from .image import Image
from .wireless import wifi
from .network import net, wireshark, arp
from .devicemanger import system
from .torrequests import tor
from .record import screen, webcam, record
from .server import server




import subprocess
import os
from .info import Tools
from .exceptions import *

class Connect_sub:
    shell = True # is shell
    stdout = subprocess.PIPE # being able to read response
    stderr = subprocess.DEVNULL # throw error to null
    found_return = "successfully activated"
    op = ["nt"] # not supported os list (I didn't add all unsupported os's)
class Wifi:
    def connect(self, ssid: str, password: str=None): # connect to network function
        if os.name in Connect_sub.op: # making sure that os supported
            raise OperatingSystemERROR("this operating system is not supported")
        if password == None: # checking if uses password or not (value change)
            result =  wifi.ssid_only( ssid)
        else:
            result = wifi.secret_connect( ssid, password)

        if "successfully activated" in result: # checking command result
            return "Connected"
        else:
            return "Failed"

    def ssid_only(self, ssid): # this function will run if network not using secret/password
        command = Tools.nmcli.SSID_ONLY.replace("(ssid)", ssid) # adding ssid to command
        # running the command
        result = subprocess.Popen(
            command,
            shell=Connect_sub.shell,
            stdout=Connect_sub.stdout,
            stderr=Connect_sub.stderr
        ).stdout.read().decode()
        return result

    def secret_connect(self, ssid, password): # It'll run if ssid and password are both entered
        # adding ssid and password to command.
        command = Tools.nmcli.SECRET_CONNECT.replace("(ssid)", ssid).replace("(secret)", password)
        # running the command
        result = subprocess.Popen(
            command,
            shell=Connect_sub.shell,
            stdout=Connect_sub.stdout,
            stderr=Connect_sub.stderr
        ).stdout.read().decode()
        return result
# naming class
wifi = Wifi()


from PIL import Image as Im
from PIL.ExifTags import TAGS
import os.path
from .exceptions import *



class Image:
    def isfile(self, filename):

        result =  os.path.exists(filename) # checking if file exist

        if result == False:
            raise FileNotFound(f"file not found: {filename}") # file exception

        elif result == True:
            return result


    def extracexif(self, filename: str):
        if Image.isfile(filename) != False: # making sure that file exist
            try:
                image = Im.open(filename) # process image with pillow
                image_data = {} # creating data dict
                for key, value in image._getexif().items(): # extracting exif data from image
                    if key in TAGS: # checking data
                        image_data[TAGS[key]] = value # adding keys and values to the dict
                return image_data
            except Exception as error:
                raise ExifExtractError(f"exif error : {error}")
Image = Image()


import socket
from .exceptions import *








class _Server_info:
    # server connect timeout
    CONNECT_TIMOUT = 9





class Server:
    def __init__(self):

        self.set_socket = set_socket

    def get_banner(self, address: str, port: str, timeout: int = 5):
        s = socket.socket()
        s.settimeout(timeout)
        try:
            s.connect((address, port))
            return s.recv(1024).decode()
        except socket.timeout:
            raise SocketConnectionError("Time out")
        except socket.error as exc:
            raise SocketConnectionError(f"connection error: {exc}")


    def portscan(self, ip: str, port: int, timeout=3):
        s = socket.socket(socket.AF_INET, socket.SOCK_STREAM) # create socket
        s.settimeout(int(timeout)) # set timeout
        try:
            conn = s.connect_ex((ip, port)) #connect to ip/port
            if (conn == 0): # if conn not 0 connection closed
                return True
            else:
                return False
        except socket.timeout:
            raise SocketConnectionError("Time out")
        except socket.error as exc:
            raise SocketConnectionError(f"connection error: {exc}")


class set_socket:
    def __init__(self, host: str, port: int, sock_arg1=socket.AF_INET, sock_arg2=socket.SOCK_STREAM):
        # set values
        self.host = host
        self.port = port
        # set server socket
        self.server = socket.socket(sock_arg1, sock_arg2)


    def connect(self, host: int=None, port: int=None, timeout = int(_Server_info.CONNECT_TIMOUT)):
        # check if new host and port are given
        if host != None:
            address = (str(host), int(port))
        else:
            address = (str(self.host), int(self.port))
        try:
            self.server.settimeout(int(timeout))  # set timeout
            # connect to server
            self.server.connect(address)
            return True
        except:
            raise SocketConnectionError("Error: connection error")



    def sendpacket(self, packet, host: str=None, port: int=None, connected=True, auto_close=False, encoding = "utf-8"):

        # check if new host and port are given
        if host != None:
            address = (host, port)

            # checking if user already connected
            if connected == False:
                set_socket.connect(self, host, port)
        else:
            address = (str(self.host), int(self.port))
            # checking if user already connected
            if connected == False:
                set_socket.connect(self)

        # check if packet is bytes
        if not isinstance(packet, bytes):
            # if packet is not bytes encode it into bytes
            packet = packet.encode(encoding)

        #checking if auto close enabled


        # send packet
        if self.server.sendto(packet, address):
            if auto_close == True:
                set_socket.close(self)
            return True
        else:
            if auto_close == True:
                set_socket.close(self)
            return False



    def close(self):
        # terminate connection
        return self.server.close()

    def recv(self, bufsize):
        # receive data
        return self.server.recv(bufsize)

server = Server()



class sock:
    DEFAULT_SOCKET_TIMEOUT = 10
    RDP_PORT = 3389
    SSH_PORT = 22
class webcam_info:
    DEFAULT_CAMERA_NUM = 0
    VIDEO_FORMATE = ".avi"

    DEFAULT_FPS = 30


class httpbin:
    IP = "http://httpbin.org/ip"

class system:
    WIN_DEFAULT_CMD_SAFE_RETURNCODE = 0
    LINUX_DEFAULT_CMD_SAFE_RETURNCODE = 0

    _SYS_PLATFORMS = {
    "Windows": ["win32", "win16",
                "Microsoft",
                "Microsoft Windows",
                "Windows"],
                "Linux": ["linux", "Linux"],
                "MacOS": ["Darwin"],
                "Java": ["java"]
            }
class request:
    DEFAULT_REQUEST_TIMEOUT = 10

class Tools:
    class nmcli:
        SSID_ONLY = "sudo nmcli dev wifi connect (ssid)"
        SECRET_CONNECT = 'sudo nmcli dev wifi connect (ssid) password "(secret)"'

    class aircrack:
        MONITOR_START = "airmon-ng start"
        MONITOR_STOP = "airmon-ng stop"

    class ettercap:
        ARP_START = "sudo ettercap -T -S -i (interface) -M arp:remote /(router)// /(device)//"

    class wireshark:
        MONITOR_DEVICE = 'wireshark -i (interface) -k -Y "ip.addr == (device)"'


class API:
    IPINFO_API = 'http://ip-api.com/json'


import datetime
import cv2
import numpy
import numpy as np
from PIL import ImageGrab
import os.path
import warnings
from .info import webcam_info
import pyautogui
class _webcam:
    def __init__(self):
        # shared record class is class that contains functions that multiple functions needs or neither
        self._shared_record = _shared_recored()
    def get_frame(self, camera: int=webcam_info.DEFAULT_CAMERA_NUM, capturing=False):
        # camera argument is which camera will capture
        # camera variable is to capture picture
        if capturing == False:
            camera = cv2.VideoCapture(camera)
        else:
            camera = self.camera
        # read picture frame
        ret, frame = camera.read()
        # return captured frame
        _ = frame
        return frame

    '''
    def _listfiles(self, path: str='.'):
        # return list of files/images in folder
        return glob.glob(path)
    '''
    def frame_to_image(self, filename: str, frame: numpy.ndarray):
        # check if file exists before writing if it's exists It'll just throw a warning
        '''
        if _webcam._isfile(self, filename) == True:
            warnings.warn(f"WARNING: {filename} already exists.")
        '''
        # write image
        return cv2.imwrite(filename, frame)




    def webcamshot(self, filename: str, camera: int=webcam_info.DEFAULT_CAMERA_NUM):
        frame = _webcam.get_frame(self, camera=camera)

        return _webcam.frame_to_image(self, filename=filename, frame=frame)
    def capture_video(self,filename: str, seconds: int, camera: int=webcam_info.DEFAULT_CAMERA_NUM, size=None, fps: int=int(webcam_info.DEFAULT_FPS)):
        # check if file exists before writing if it's exists It'll just throw a warning
        if _webcam._isfile(self, filename) == True:
            warnings.warn(f"WARNING: {filename} already exists.")
        self.captures = []
        # prepare camera
        self.camera = cv2.VideoCapture(camera)
        # process time to be able to control the while loop run time
        entered_time = datetime.datetime.now() + datetime.timedelta(seconds=seconds)

        # basically It'll run until the entered end's
        while datetime.datetime.now() < entered_time:
            '''
            Now It'll keep saving camera frames until the time end's
            capturing is true because already prepared the camera
            '''
            frame = _webcam.get_frame(self, camera=camera, capturing=True)
            '''
            saving camera frames in self.captures
            '''
            self.captures.append(frame)

        '''
         writer is the function that used to write the videos frames
         frame is the last entered frame in self.captures
        '''
        writer = self._shared_record.write_video(filename, frame=self.captures[-1], size=size, fps=fps)
        for frame in range(len(self.captures)):
            writer.write(self.captures[frame])

        # just like releasing a pen from the paper
        return writer.release()
    def _isfile(self, filename: str):
        # check if path exists
        return os.path.exists(filename)


class _shared_recored:
    # shared record class is class that contains functions that multiple functions needs or neither
    def colorframe(self, frame):

        # color frame
        return cv2.cvtColor(frame, cv2.COLOR_BGR2RGB)
    def write_video(self,filename: str='', frame=None, size=None, fps: int=int(webcam_info.DEFAULT_FPS)):

        # get frame size
        height, width, layers = frame.shape

        # making sure to get frame size
        if size == None:
            size = (width, height)
        # process frame to video file
        return cv2.VideoWriter(filename,
                                  cv2.VideoWriter_fourcc(*'DIVX'),
                                  int(fps),
                                  size
                                  )

class _screen:
    def __init__(self):
        # shared record class is class that contains functions that multiple functions needs or neither
        self._shared_record = _shared_recored()


    def screen_frame(self):
        # grab screen size
        width, height = pyautogui.size()
        '''
        apply the screen size to tuple object
        '''
        siz = (0, 0, int(width), int(height))
        # screenshot frame
        frame = ImageGrab.grab(siz)
        # turn the frame to ndarray data type
        frame = np.array(frame)

        '''
        return fixed color frame
        '''
        return self._shared_record.colorframe(frame)


    def screenshot(self, filename: str):
        frame = _screen.screen_frame(self)
        '''
        get screen frame and write it to file
        '''
        return cv2.imwrite(filename, frame)


    def capture_video(self, filename: str, seconds: int, fps: int=int(webcam_info.DEFAULT_FPS), size=None):
        self.captures = []

        # process time to be able to control the while loop run time
        entered_time = datetime.datetime.now() + datetime.timedelta(seconds=seconds)

        # basically It'll run until the entered end's
        while datetime.datetime.now() < entered_time:

            frame = _screen.screen_frame(self)
            '''
            append the screenshot data to captures list
            '''
            self.captures.append(frame)
        '''
         writer is the function that used to write the videos frames
         frame is the last entered frame in self.captures
        '''
        writer = self._shared_record.write_video(filename, frame=self.captures[-1], size=size, fps=fps)
        for frame in range(len(self.captures)):
            writer.write(self.captures[frame])
        return writer.release()



screen = _screen()
webcam = _webcam()
record = _shared_recored()


from setuptools import setup, find_packages


with open("README.md", "r", encoding="utf-8") as f:
    long_description = f.read()

setup(
  name='hek',
  version='0.3.0',
  description='A python library mostly used for pentesting and automate some tasks.',
  long_description=long_description,
  long_description_content_type='text/markdown',
  url='https://github.com/greedalbadi/hek',
  author='greed albadi',
  author_email='greedalbadi@gmail.com',
  project_urls={
      'Source': 'https://github.com/greedalbadi/hek',
      'Report Bugs': 'https://github.com/greedalbadi/hek/issues',
      'Download': 'https://pypi.org/project/PyScaffold/#files',
      'Documentation': 'https://github.com/greedalbadi/hek/blob/master/README.md'
  },
  license='MIT',
  keywords=["python", "pentesting", "automation", "stream", "http", "education"],
  packages=find_packages(),
  install_requires=['pillow', "psutil", "requests", "requests[socks]",
                    "numpy", "pyautogui", "datetime", "opencv-python"
                    ]
)